summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNicolas Goaziou <n.goaziou@gmail.com>2011-06-26 18:51:28 +0200
committerNicolas Goaziou <n.goaziou@gmail.com>2011-06-29 12:00:43 +0200
commit39d4bfa0e813ec62f6699f57e8ea7fcaad8835d8 (patch)
tree8ab9cfd5253e6cb26ba9e32e92eb53faf5223030
parenta9e0449f23440a1555b39b457eb8d955b59485b8 (diff)
downloadorg-mode-39d4bfa0e813ec62f6699f57e8ea7fcaad8835d8.tar.gz
Rename org-export-footnotes-markers to org-export-footnotes-seen
* lisp/org-exp.el (org-export-footnotes-data): change docstring. (org-export-footnotes-seen): renamed from org-export-footnotes-markers. * lisp/org-ascii.el (org-export-as-ascii): apply change. * lisp/org-docbook.el (org-export-as-docbook): apply change. * lisp/org-footnote.el (org-footnote-normalize): apply change. * lisp/org-html.el (org-export-as-html): apply change. * lisp/org-latex.el (org-export-as-latex): apply change.
-rw-r--r--lisp/org-ascii.el2
-rw-r--r--lisp/org-docbook.el2
-rw-r--r--lisp/org-exp.el7
-rw-r--r--lisp/org-footnote.el6
-rw-r--r--lisp/org-html.el2
-rw-r--r--lisp/org-latex.el4
6 files changed, 12 insertions, 11 deletions
diff --git a/lisp/org-ascii.el b/lisp/org-ascii.el
index 6469a1a..680c930 100644
--- a/lisp/org-ascii.el
+++ b/lisp/org-ascii.el
@@ -291,7 +291,7 @@ publishing directory."
(buffer-substring
(if (org-region-active-p) (region-beginning) (point-min))
(if (org-region-active-p) (region-end) (point-max))))
- (org-export-footnotes-markers nil)
+ (org-export-footnotes-seen nil)
(org-export-footnotes-data (org-footnote-all-labels 'with-defs))
(lines (org-split-string
(org-export-preprocess-string
diff --git a/lisp/org-docbook.el b/lisp/org-docbook.el
index 087817d..a622056 100644
--- a/lisp/org-docbook.el
+++ b/lisp/org-docbook.el
@@ -524,7 +524,7 @@ publishing directory."
(buffer-substring
(if region-p (region-beginning) (point-min))
(if region-p (region-end) (point-max))))
- (org-export-footnotes-markers nil)
+ (org-export-footnotes-seen nil)
(org-export-footnotes-data (org-footnote-all-labels 'with-defs))
(lines
(org-split-string
diff --git a/lisp/org-exp.el b/lisp/org-exp.el
index c4174c5..3674d19 100644
--- a/lisp/org-exp.el
+++ b/lisp/org-exp.el
@@ -623,10 +623,11 @@ table.el tables."
(defvar org-last-level nil) ; dynamically scoped variable
(defvar org-min-level nil) ; dynamically scoped variable
(defvar org-levels-open nil) ; dynamically scoped parameter
-(defvar org-export-footnotes-markers nil
- "Alist of markers used for footnotes, along with their associated definition.")
(defvar org-export-footnotes-data nil
- "Alist of labels used in buffers, along with their associated definition.")
+ "Alist of labels used in buffers, along with their definition.")
+(defvar org-export-footnotes-seen nil
+ "Alist of labels encountered so far by the exporter, along with their definition.")
+
(defconst org-export-plist-vars
'((:link-up nil org-export-html-link-up)
diff --git a/lisp/org-html.el b/lisp/org-html.el
index 80e0738..a343647 100644
--- a/lisp/org-html.el
+++ b/lisp/org-html.el
@@ -1183,7 +1183,7 @@ PUB-DIR is set, use this as the publishing directory."
(if region-p (region-beginning) (point-min))
(if region-p (region-end) (point-max))))
(org-export-have-math nil)
- (org-export-footnotes-markers nil)
+ (org-export-footnotes-seen nil)
(org-export-footnotes-data (org-footnote-all-labels 'with-defs))
(lines
(org-split-string
diff --git a/lisp/org-latex.el b/lisp/org-latex.el
index 743c19c..ede3275 100644
--- a/lisp/org-latex.el
+++ b/lisp/org-latex.el
@@ -775,7 +775,7 @@ when PUB-DIR is set, use this as the publishing directory."
(org-export-latex-set-initial-vars ext-plist arg)
(setq org-export-opt-plist org-export-latex-options-plist
org-export-footnotes-data (org-footnote-all-labels 'with-defs)
- org-export-footnotes-markers nil
+ org-export-footnotes-seen nil
org-export-latex-footmark-seen nil)
(org-install-letbind)
(run-hooks 'org-export-latex-after-initial-vars-hook)
@@ -2431,7 +2431,7 @@ The conversion is made depending of STRING-BEFORE and STRING-AFTER."
(lbl (car ref))
(def (nth 1 (assoc (string-to-number lbl)
(mapcar (lambda (e) (cdr e))
- org-export-footnotes-markers)))))
+ org-export-footnotes-seen)))))
;; Fix body for footnotes ending on a link or a list and
;; remove definition from buffer.
(setq def
diff --git a/lisp/org-footnote.el b/lisp/org-footnote.el
index 052a55e..3555dc2 100644
--- a/lisp/org-footnote.el
+++ b/lisp/org-footnote.el
@@ -508,7 +508,7 @@ Additional note on `org-footnote-insert-pos-for-preprocessor':
(outline-regexp
(concat "\\*" (if nstars (format "\\{1,%d\\} " nstars) "+ ")))
;; Determine the highest marker used so far.
- (ref-table (when pre-process-p org-export-footnotes-markers))
+ (ref-table (when pre-process-p org-export-footnotes-seen))
(count (if (and pre-process-p ref-table)
(apply 'max (mapcar (lambda (e) (nth 1 e)) ref-table))
0))
@@ -628,9 +628,9 @@ Additional note on `org-footnote-insert-pos-for-preprocessor':
ref-table "\n\n")
"\n\n")
;; When exporting, add newly insert markers along with their
;; associated definition to `org-export-footnotes-markers'.
(when pre-process-p
- (setq org-export-footnotes-markers ref-table)))
+ (setq org-export-footnotes-seen ref-table)))
;; Else, insert each definition at the end of the section
;; containing their first reference. Happens only in Org
;; files with no special footnote section, and only when
@@ -628,9 +628,9 @@ Additional note on `org-footnote-insert-pos-for-preprocessor':
"\n\n")
;; When exporting, add newly insert markers along with their
- ;; associated definition to `org-export-footnotes-markers'.
+ ;; associated definition to `org-export-footnotes-seen'.
(when pre-process-p